==> mediaproxy-1.7.2.tbz: mediaproxy/web/config/phone_images.php <==
<?php

// array with mappings between User Agents and images
$userAgentImages = array("Asterisk"       => "asterisk.png",
                         "AVM FRITZ"      => "avm-fritzbox-wlan.png",
                         "Cisco ATA"      => "cisco-ata.png",
                         "Cisco.*Gateway" => "cisco.png",
                         "CSCO"           => "cisco-7960.png",
                         "DrayTek"        => "draytek-vigor2600vg.png",
                         "eStara"         => "eStara.png",
                         "Eyebeam"        => "eyebeam.png",
                         "Grandstream"    => "handytone.png",
                         "ipDialog"       => "ipDialog.png",
                         "Linksys\/PAP"   => "linksys-pap2.png",
                         "Session.*Wave"  => "session.png",
                         "SIPPS"          => "sipps.png",
                         "Sipura"         => "spa2000.png",
                         "sjphone"        => "sjphone.png",
                         "Snom100"        => "snom100.png",
                         "Snom(190|200)"  => "snom200.png",
                         "Snom320"        => "snom320.png",
                         "Snom360"        => "snom360.png",
                         "snomSoft"       => "snom360.png",
                         "Talkin"         => "xten.png",
                         "unidata"        => "hitachi-wip5000.png",
                         "Vizufon"        => "vizufon.png",
                         "voipster"       => "zoep.png",
                         "Windows RTC"    => "messenger.png",
                         "X-Lite"         => "xten.png",
                         "X-PRO"          => "xten.png",
                         "ZyXEL P2000W"   => "zyxel-p2000.png",
                         "-IMVP"          => "innomedia-mta5000.png",
                         "3610\/"         => "siemens-3610.png",
                         "cirpack"        => "cirpack.png",
                         "Brcm Callctrl"  => "aastra.png",
                         "Audiocodes-Sip-Gateway-MP-124" => "audiocodes-mp124.png"
                         );

?>

==> mediaproxy-1.8.2_4.tbz: mediaproxy/web/config/phone_images.php <==
<?php

// array with mappings between User Agents and images
$userAgentImages = array("Asterisk"       => "asterisk.png",
                         "AVM FRITZ"      => "avm-fritzbox-wlan.png",
                         "Cisco ATA"      => "cisco-ata.png",
                         "Cisco.*Gateway" => "cisco.png",
                         "CSCO"           => "cisco-7960.png",
                         "DrayTek"        => "draytek-vigor2600vg.png",
                         "eStara"         => "eStara.png",
                         "Eyebeam"        => "eyebeam.png",
                         "Grandstream"    => "handytone.png",
                         "ipDialog"       => "ipDialog.png",
                         "Linksys\/PAP"   => "linksys-pap2.png",
                         "Session.*Wave"  => "session.png",
                         "SIPPS"          => "sipps.png",
                         "Sipura"         => "spa2000.png",
                         "sjphone"        => "sjphone.png",
                         "Snom100"        => "snom100.png",
                         "Snom(190|200)"  => "snom200.png",
                         "Snom320"        => "snom320.png",
                         "Snom360"        => "snom360.png",
                         "snomSoft"       => "snom360.png",
                         "Talkin"         => "xten.png",
                         "unidata"        => "hitachi-wip5000.png",
                         "Vizufon"        => "vizufon.png",
                         "voipster"       => "zoep.png",
                         "Windows RTC"    => "messenger.png",
                         "X-Lite"         => "xten.png",
                         "X-PRO"          => "xten.png",
                         "ZyXEL P2000W"   => "zyxel-p2000.png",
                         "-IMVP"          => "innomedia-mta5000.png",
                         "3610\/"         => "siemens-3610.png",
                         "cirpack"        => "cirpack.png",
                         "Brcm-Callctrl"  => "webstarepx2203.png",
                         "Audiocodes-Sip-Gateway-MP" => "audiocodes-mp124.png",
                         "Nokia"	  => "nokia.png",
                         "CopperJet"	  => "copperjet16162p.png"
                         );

?>
